"""
CLI System - Command-line interface for strataregula.

Provides a rich command-line interface with:
- Interactive pipeline building
- STDIN processing
- File processing
- Pipeline management
- Help and documentation
"""

from .main import main

__all__ = [
    "main",
]
